@@ -125,7 +125,7 @@ void ToolTipManager::prepareToolTip()
     showToolTip( d->item );
 }
 
-void ToolTipManager::showToolTip( QModelIndex menuItem )
+void ToolTipManager::showToolTip( const QModelIndex &menuItem )
 {
     if (QApplication::mouseButtons() & Qt::LeftButton) {
         return;
